@@ -3,32 +3,27 @@
 import json
 import requests
 from importlib.metadata import version
-import subprocess
 
 class Updater:
 
     @staticmethod
-    def checkUpdate():        
-        print("Checking latest Cheese release...")
-        print("")
+    def checkUpdate():     
         vers = version("CheeseFramework")
         try:
             r = requests.get("https://pypi.org/pypi/CheeseFramework/json").text
             aversion = json.loads(r)["info"]["version"]
         except:
             print("Cannot check latest Cheese version")
+            return
 
         if (vers != aversion):
+            print(30*"=")
             print(f"You have got version {vers} but the latest Cheese is {aversion}")
-            accept = input("Would you like to update? [y/n] ")
-            if (accept.startswith("y")):
-                Updater.update()
+            print("Update Cheese with command:")
+            print("")
+            print(f"pip install CheeseFramework=={aversion}")
+            print("")
+            print(30*"=")
+            print("")
 
 
-    @staticmethod
-    def update():
-        subprocess.run("git pull", shell=True)
-        print("")
-        print(f"Cheese was updated on lastest release :)")
-        print("")
-
